(dashify kw)(headlessui->reagent component)Convert a @headlessui/react component into a reagent component.
Convert a @headlessui/react component into a reagent component.
(pass-through-props props)We need props appropriate for a reagent component. We receive React style props that have been shallowly converted to a CLJ hashmap. Finishes the conversion to reagent props.
We need props appropriate for a reagent component. We receive React style props that have been shallowly converted to a CLJ hashmap. Finishes the conversion to reagent props.
(props-and-children args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |